==> ejc-production-api-3.0.0-20220621.041108-173-sources.jar: com/ejianc/business/production/task/vo/DelivergoodsVO.java <==
package com.ejianc.business.production.task.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 发货信息
 * 
 * @author generator
 * 
 */
public class DelivergoodsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Long taskTransportId; // 任务单运输主键id
    private String taskTransportCode; // 任务单运输名称
    private Long taskId; // 生产任务单id
    private String taskCode; // 生产任务单单号
    private Long shippersVehicleId; // 运输商车辆主键id
    private Long customerId; // 客户主键id
    private String customerName; // 客户名称
    private Long projectId; // 工程id
    private String projectName; // 工程名称
    private Long worksiteId; // 工地id
    private String worksiteName; // 工地名称

    private Long productId; // 产品id
    private String productName; // 产品名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date deliverDate; // 发货日期
    private BigDecimal temperature; // 温度
    private String shippersVehicleCode; // 车牌照号
    private BigDecimal tare; // 皮重
    private BigDecimal gross; // 毛重
    private BigDecimal net; // 净重
    private BigDecimal distance; // 远距
    private BigDecimal freight; // 运费
    private BigDecimal transportCount; // 运输重量
    private Integer transportStatue; // 发货状态
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private String printCustomerName; // 打印客户名称
    private String printProductName; // 打印产品名称
    private String printWorksiteName; // 打印工地名称
    private String printSupplyName; // 打印供应商名称
    private String shipperMName; //运输商基本信息名称
    private Long shipperMId; // 运输商管理档案主键
    private Long unitId; // 机组id
    private String unitName; // 机组名称
    private Integer sort; // 序号
    private String addCount; // 外加剂


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode="ShippersVehicleRef")
    public Long getShippersVehicleId() {
        return shippersVehicleId;
    }
    @ReferDeserialTransfer
    public void setShippersVehicleId(Long shippersVehicleId) {
        this.shippersVehicleId = shippersVehicleId;
    }

    @ReferSerialTransfer(referCode="ProductiontasktransportRef")
    public Long getTaskTransportId() {
        return taskTransportId;
    }
    @ReferDeserialTransfer
    public void setTaskTransportId(Long taskTransportId) {
        this.taskTransportId = taskTransportId;
    }
    public String getTaskTransportCode() {
        return taskTransportCode;
    }

    public void setTaskTransportCode(String taskTransportCode) {
        this.taskTransportCode = taskTransportCode;
    }
    @ReferSerialTransfer(referCode="ProductiontaskRef")
    public Long getTaskId() {
        return taskId;
    }
    @ReferDeserialTransfer
    public void setTaskId(Long taskId) {
        this.taskId = taskId;
    }
    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }
    @ReferSerialTransfer(referCode="CustomerinfoRef")
    public Long getCustomerId() {
        return customerId;
    }
    @ReferDeserialTransfer
    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    @ReferSerialTransfer(referCode="ProjectInfoRef")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode="ConstructionsiteRef")
    public Long getWorksiteId() {
        return worksiteId;
    }
    @ReferDeserialTransfer
    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    @ReferSerialTransfer(referCode="ProjectInfoRef")
    public Long getProductId() {
        return productId;
    }
    @ReferDeserialTransfer
    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Date getDeliverDate() {
        return deliverDate;
    }

    public void setDeliverDate(Date deliverDate) {
        this.deliverDate = deliverDate;
    }
    public BigDecimal getTemperature() {
        return temperature;
    }

    public void setTemperature(BigDecimal temperature) {
        this.temperature = temperature;
    }
    public String getShippersVehicleCode() {
        return shippersVehicleCode;
    }

    public void setShippersVehicleCode(String shippersVehicleCode) {
        this.shippersVehicleCode = shippersVehicleCode;
    }
    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }
    public BigDecimal getGross() {
        return gross;
    }

    public void setGross(BigDecimal gross) {
        this.gross = gross;
    }
    public BigDecimal getNet() {
        return net;
    }

    public void setNet(BigDecimal net) {
        this.net = net;
    }
    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }
    public BigDecimal getFreight() {
        return freight;
    }

    public void setFreight(BigDecimal freight) {
        this.freight = freight;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public BigDecimal getTransportCount() {
        return transportCount;
    }

    public void setTransportCount(BigDecimal transportCount) {
        this.transportCount = transportCount;
    }

    public Integer getTransportStatue() {
        return transportStatue;
    }

    public void setTransportStatue(Integer transportStatue) {
        this.transportStatue = transportStatue;
    }

    public String getPrintCustomerName() {
        return printCustomerName;
    }

    public void setPrintCustomerName(String printCustomerName) {
        this.printCustomerName = printCustomerName;
    }

    public String getPrintProductName() {
        return printProductName;
    }

    public void setPrintProductName(String printProductName) {
        this.printProductName = printProductName;
    }

    public String getPrintWorksiteName() {
        return printWorksiteName;
    }

    public void setPrintWorksiteName(String printWorksiteName) {
        this.printWorksiteName = printWorksiteName;
    }

    public String getPrintSupplyName() {
        return printSupplyName;
    }

    public void setPrintSupplyName(String printSupplyName) {
        this.printSupplyName = printSupplyName;
    }
    @ReferSerialTransfer(referCode="ShippersRef")
    public Long getShipperMId() {
        return shipperMId;
    }

    @ReferDeserialTransfer
    public void setShipperMId(Long shipperMId) {
        this.shipperMId = shipperMId;
    }
    @ReferSerialTransfer(referCode="UnitRef")
    public Long getUnitId() {
        return unitId;
    }
    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public String getShipperMName() {
        return shipperMName;
    }

    public void setShipperMName(String shipperMName) {
        this.shipperMName = shipperMName;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public String getAddCount() {
        return addCount;
    }

    public void setAddCount(String addCount) {
        this.addCount = addCount;
    }
}

==> ejc-production-api-3.0.0-20220706.114239-205-sources.jar: com/ejianc/business/production/task/vo/DelivergoodsVO.java <==
package com.ejianc.business.production.task.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 发货信息
 * 
 * @author generator
 * 
 */
public class DelivergoodsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Long taskTransportId; // 任务单运输主键id
    private String taskTransportCode; // 任务单运输名称
    private Long taskId; // 生产任务单id
    private String taskCode; // 生产任务单单号
    private Long shippersVehicleId; // 运输商车辆主键id
    private Long customerId; // 客户主键id
    private String customerName; // 客户名称
    private Long projectId; // 工程id
    private String projectName; // 工程名称
    private Long worksiteId; // 工地id
    private String worksiteName; // 工地名称

    private Long productId; // 产品id
    private String productName; // 产品名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date deliverDate; // 发货日期
    private BigDecimal temperature; // 温度
    private String shippersVehicleCode; // 车牌照号
    private BigDecimal tare; // 皮重
    private BigDecimal gross; // 毛重
    private BigDecimal net; // 净重
    private BigDecimal distance; // 远距
    private BigDecimal freight; // 运费
    private BigDecimal transportCount; // 运输重量
    private Integer transportStatue; // 发货状态
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private String printCustomerName; // 打印客户名称
    private String printProductName; // 打印产品名称
    private String printWorksiteName; // 打印工地名称
    private String printSupplyName; // 打印供应商名称
    private String shipperMName; //运输商基本信息名称
    private Long shipperMId; // 运输商管理档案主键
    private Long unitId; // 机组id
    private String unitName; // 机组名称
    private Integer sort; // 序号
    private String addCount; // 外加剂
    private String transportRoute; // 行车路线


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode="ShippersVehicleRef")
    public Long getShippersVehicleId() {
        return shippersVehicleId;
    }
    @ReferDeserialTransfer
    public void setShippersVehicleId(Long shippersVehicleId) {
        this.shippersVehicleId = shippersVehicleId;
    }

    @ReferSerialTransfer(referCode="ProductiontasktransportRef")
    public Long getTaskTransportId() {
        return taskTransportId;
    }
    @ReferDeserialTransfer
    public void setTaskTransportId(Long taskTransportId) {
        this.taskTransportId = taskTransportId;
    }
    public String getTaskTransportCode() {
        return taskTransportCode;
    }

    public void setTaskTransportCode(String taskTransportCode) {
        this.taskTransportCode = taskTransportCode;
    }
    @ReferSerialTransfer(referCode="ProductiontaskRef")
    public Long getTaskId() {
        return taskId;
    }
    @ReferDeserialTransfer
    public void setTaskId(Long taskId) {
        this.taskId = taskId;
    }
    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }
    @ReferSerialTransfer(referCode="CustomerinfoRef")
    public Long getCustomerId() {
        return customerId;
    }
    @ReferDeserialTransfer
    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    @ReferSerialTransfer(referCode="ProjectInfoRef")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode="ConstructionsiteRef")
    public Long getWorksiteId() {
        return worksiteId;
    }
    @ReferDeserialTransfer
    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    @ReferSerialTransfer(referCode="ProjectInfoRef")
    public Long getProductId() {
        return productId;
    }
    @ReferDeserialTransfer
    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Date getDeliverDate() {
        return deliverDate;
    }

    public void setDeliverDate(Date deliverDate) {
        this.deliverDate = deliverDate;
    }
    public BigDecimal getTemperature() {
        return temperature;
    }

    public void setTemperature(BigDecimal temperature) {
        this.temperature = temperature;
    }
    public String getShippersVehicleCode() {
        return shippersVehicleCode;
    }

    public void setShippersVehicleCode(String shippersVehicleCode) {
        this.shippersVehicleCode = shippersVehicleCode;
    }
    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }
    public BigDecimal getGross() {
        return gross;
    }

    public void setGross(BigDecimal gross) {
        this.gross = gross;
    }
    public BigDecimal getNet() {
        return net;
    }

    public void setNet(BigDecimal net) {
        this.net = net;
    }
    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }
    public BigDecimal getFreight() {
        return freight;
    }

    public void setFreight(BigDecimal freight) {
        this.freight = freight;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public BigDecimal getTransportCount() {
        return transportCount;
    }

    public void setTransportCount(BigDecimal transportCount) {
        this.transportCount = transportCount;
    }

    public Integer getTransportStatue() {
        return transportStatue;
    }

    public void setTransportStatue(Integer transportStatue) {
        this.transportStatue = transportStatue;
    }

    public String getPrintCustomerName() {
        return printCustomerName;
    }

    public void setPrintCustomerName(String printCustomerName) {
        this.printCustomerName = printCustomerName;
    }

    public String getPrintProductName() {
        return printProductName;
    }

    public void setPrintProductName(String printProductName) {
        this.printProductName = printProductName;
    }

    public String getPrintWorksiteName() {
        return printWorksiteName;
    }

    public void setPrintWorksiteName(String printWorksiteName) {
        this.printWorksiteName = printWorksiteName;
    }

    public String getPrintSupplyName() {
        return printSupplyName;
    }

    public void setPrintSupplyName(String printSupplyName) {
        this.printSupplyName = printSupplyName;
    }
    @ReferSerialTransfer(referCode="ShippersRef")
    public Long getShipperMId() {
        return shipperMId;
    }

    @ReferDeserialTransfer
    public void setShipperMId(Long shipperMId) {
        this.shipperMId = shipperMId;
    }
    @ReferSerialTransfer(referCode="UnitRef")
    public Long getUnitId() {
        return unitId;
    }
    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public String getShipperMName() {
        return shipperMName;
    }

    public void setShipperMName(String shipperMName) {
        this.shipperMName = shipperMName;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public String getAddCount() {
        return addCount;
    }

    public void setAddCount(String addCount) {
        this.addCount = addCount;
    }

    public String getTransportRoute() {
        return transportRoute;
    }

    public void setTransportRoute(String transportRoute) {
        this.transportRoute = transportRoute;
    }
}
